BucketQueueU8

Struct BucketQueueU8 

pub struct BucketQueueU8 {
    queue: BucketQueue8,
}
A fixed 8-bit-universe max-priority queue. BinaryHeap::peek_mut can be faster for replacements in tiny queues.

Fields

queue: BucketQueue8

Implementations

Source

impl BucketQueueU8

pub fn new() -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn peek(&self) -> Option<u8>

pub fn push(&mut self, value: u8)

Panics

Panics if the queue already contains u32::MAX values.

pub fn pop(&mut self) -> Option<u8>

pub fn replace(&mut self, value: u8) -> Option<u8>

Unconditionally replaces the greatest value, or inserts into an empty queue.

pub fn clear(&mut self)